# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

%global tarball_includes_docs 0

Summary:	Clean up and pretty-print HTML/XHTML/XML
Name:		tidyp
Version:	1.04
Release:	15.%{__distinit}%{__distvers}
License:	W3C
URL:		http://github.com/petdance/tidyp
Source0:	http://github.com/downloads/petdance/tidyp/tidyp-%{version}.tar.gz
Source1:	testall.sh
Source2:	testcases.txt
Source3:	testone.sh
Patch0:		tidy-outfile-raw.patch
Patch1:		tidyp-1.04-aarch64.patch
Patch3:		tidyp-1.02-format.patch
BuildRequires:	coreutils
BuildRequires:	gcc
BuildRequires:	make
%if %{tarball_includes_docs}
BuildRequires:	doxygen
BuildRequires:	libxslt
%endif
Requires:	libtidyp%{?_isa} = %{version}-%{release}

%description
tidyp is a fork of tidy on SourceForge. The library name is "tidyp", and the
command-line tool is also "tidyp" but all internal API stays the same.

%package -n libtidyp
Summary:	Shared libraries for tidyp

%description -n libtidyp
Shared libraries for tidyp.

%package -n libtidyp-devel
Summary:	Development files for libtidyp
Requires:	libtidyp%{?_isa} = %{version}-%{release}

%description -n libtidyp-devel
Development files for libtidyp.

%prep
%setup -q

# Missing test files
cp -a %{SOURCE1} %{SOURCE2} %{SOURCE3} tests/

# Fix directory layout cock-up in upstream tarball
mv tests/input/input tests/input.real
rmdir tests/input
mv tests/input.real tests/input

# Fix mangling of output file names (#725651)
# Sent upstream: https://github.com/petdance/tidyp/pull/18
%patch0 -p1

# Tweak config.guess and config.sub to add aarch64 support (#926635)
%patch1

# Fix format string issues
# https://github.com/w3c/tidy-html5/issues/11
%patch3 -p1

# Fix permissions for debuginfo
chmod -c -x src/{mappedio.*,version.h}

%build
%configure --disable-static --disable-dependency-tracking

# Remove RPATH to libdir
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make %{?_smp_mflags}

%if %{tarball_includes_docs}
# api docs
doxygen htmldoc/doxygen.cfg

# user docs
cd htmldoc
../bin/tidyp -xml-config > tidyp-config.xml
../bin/tidyp -xml-help > tidyp-help.xml
xsltproc -o tidyp.1 tidyp1.xsl tidyp-help.xml
xsltproc -o quickref.html quickref-html.xsl tidyp-config.xml
cd -
%endif

%install
make install DESTDIR=%{buildroot}
%if %{tarball_includes_docs}
install -p -m644 -D htmldoc/tidyp.1 %{buildroot}%{_mandir}/man1/tidyp.1
%endif

%check
LD_LIBRARY_PATH=%{buildroot}%{_libdir} make check

%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
# ldconfig scriptlets replaced by RPM File Triggers from Fedora 28
%post -n libtidyp -p /sbin/ldconfig
%postun -n libtidyp -p /sbin/ldconfig
%endif

%files
%if %{tarball_includes_docs}
%doc htmldoc/*.html htmldoc/*.css htmldoc/*.gif
%{_mandir}/man1/tidyp.1*
%endif
%{_bindir}/tidyp

%files -n libtidyp
%{_libdir}/libtidyp-%{version}.so.0*

%files -n libtidyp-devel
%if %{tarball_includes_docs}
%doc htmldoc/api/*
%endif
%{_includedir}/tidyp/
%{_libdir}/libtidyp.so
%exclude %{_libdir}/libtidyp.la

%changelog
* Thu Dec  9 2021 Paul Howarth <paul@city-fan.org> - 1.04-15
- Run test suite with LD_LIBRARY_PATH pointing to tidyp library in the
  buildroot so that it can be found
- Fix dist tags for CentOS Stream

* Sun Jul 25 2021 Paul Howarth <paul@city-fan.org> - 1.04-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild
- Remove RPATH to libdir
- Fix dist tags for Alma and Rocky Linux

* Tue Feb  2 2021 Paul Howarth <paul@city-fan.org> - 1.04-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jul 29 2020 Paul Howarth <paul@city-fan.org> - 1.04-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Fri Jan 31 2020 Paul Howarth <paul@city-fan.org> - 1.04-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Sun Jul 28 2019 Paul Howarth <paul@city-fan.org> - 1.04-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sun Jul 15 2018 Paul Howarth <paul@city-fan.org> - 1.04-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Feb  6 2018 Paul Howarth <paul@city-fan.org> - 1.04-8
- ldconfig scriptlets replaced by RPM File Triggers from Fedora 28

* Fri Aug  4 2017 Paul Howarth <paul@city-fan.org> - 1.04-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild
- Drop obsoletion of libtidyp by main tidy package
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Tue Jan 26 2016 Paul Howarth <paul@city-fan.org> - 1.04-6
- Drop %%defattr, redundant since rpm 4.4

* Thu Nov 21 2013 Paul Howarth <paul@city-fan.org> - 1.04-5
- Fix format string issues (https://github.com/w3c/tidy-html5/issues/11)

* Mon Mar 25 2013 Paul Howarth <paul@city-fan.org> - 1.04-4
- Tweak config.guess and config.sub to add aarch64 support (#926635)

* Fri Jul 29 2011 Paul Howarth <paul@city-fan.org> - 1.04-3
- Fix mangling of output file names (#725651)
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Oct  1 2010 Paul Howarth <paul@city-fan.org> - 1.04-2
- Rebuild for gcc bug (#634757)

* Fri Sep 17 2010 Paul Howarth <paul@city-fan.org> - 1.04-1
- Update to 1.04 (compiler flags fixed)
- Drop upstreamed compiler flags patch
- No longer need to touch autotools-generated files
- Add test files missing from upstream tarball
- Fix upstream tarball directory layout error for test cases

* Mon May 10 2010 Paul Howarth <paul@city-fan.org> - 1.02-1
- Update to 1.02
  - Metatag check fixed
  - Missing files for "make check" included
- Drop upstreamed metatag patch
- Fix dist tag for RHEL-6 Beta
- Touch autotools-generated files in order to prevent attempted
  re-running of autotools at build time

* Mon Apr 26 2010 Paul Howarth <paul@city-fan.org> - 1.00-1
- Update to 1.00
  - Removed -Wextra compiler flag for gcc, incompatible with older versions
  - Added "check" and "tags" make targets
  - Removed commented-out code
- Add %%check section, using test data from upstream git since it was omitted
  from the distribution tarball
- Drop upstreamed parts of patches
- Merge autotools patch into cflags patch
- Add patch to update "generator" metatag properly

* Mon Mar  1 2010 Paul Howarth <paul@city-fan.org> - 0.99-2
- Main package renamed to tidyp, as per upstream
- New subpackage libtidyp (same split as tidy in Fedora)
- Upstream has now provided a proper tarball, with pre-built configure script,
  so rework build system patches and drop autotools buildreqs
- Reworked upstream tarball no longer includes docs

* Wed Feb 17 2010 Paul Howarth <paul@city-fan.org> - 0.99-1
- libtidyp forked from tidy
- Add patches to autotools build to make it work more sanely

* Tue Dec  8 2009 Paul Howarth <paul@city-fan.org> - 0.99.0-20.20091203.1
- 20091203 snapshot
- Spec housecleaning
- tidy erroneously removed whitespace, causing mangled text (#481350)

* Fri Jul 31 2009 Paul Howarth <paul@city-fan.org> - 0.99.0-19.20070615.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Mar  3 2009 Paul Howarth <paul@city-fan.org> - 0.99.0-18.20070615.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Feb 19 2008 Paul Howarth <paul@city-fan.org> - 0.99.0-17.20070615.1
- Respin (gcc 4.3.0)

* Mon Aug 27 2007 Paul Howarth <paul@city-fan.org> - 0.99.0-16.20070615.1
- Respin (BuildID)

* Fri Aug 24 2007 Paul Howarth <paul@city-fan.org> - 0.99.0-15.20070615.1
- Use standard shortname "WSC" for license tag

* Tue Jul 10 2007 Paul Howarth <paul@city-fan.org> - 0.99.0-13.20070615.1
- 15th June 2007 snapshot

* Mon Jun 25 2007 Paul Howarth <paul@city-fan.org> - 0.99.0-12.20070228.1
- Upstream has stopped releasing tarballs and advocates CVS snapshots
  instead
- 28th February 2007 snapshot
- Run setup.sh in %%prep rather than %%build
- fileio.h no longer included in -devel package

* Fri Sep 15 2006 Paul Howarth <paul@city-fan.org> - 0.99.0-10.20051026
- Add dist tag

* Tue Jun 20 2006 Paul Howarth <paul@city-fan.org> - 0.99.0-9.20051026.4
- libtidy-devel depends on libtidy, not tidy

* Mon Jan 23 2006 Paul Howarth <paul@city-fan.org> - 0.99.0-9.20051026
- Update source to 26 October 2005 version
- Bring back libtidy as per Fedora Extras package
- Never strip binaries

* Fri Oct 21 2005 Paul Howarth <paul@city-fan.org> - 0.99.0-6.20051020
- Drop obsoletes/provides for libtidy-progs, which didn't work anyway
- Update to 051020 releases of both src and docs
- Remove buildroot unconditionally in %%clean and %%install
- Don't use macros for pathnames in build-time commands, hardcode them instead
- Wrap %%description at 80 columns

* Tue Aug  9 2005 Paul Howarth <paul@city-fan.org> - 0.99.0-6.20050803
- Clean up doc generation
- Build quickref.html
- Strip binaries if we're not making a debuginfo package

* Tue Aug  9 2005 Paul Howarth <paul@city-fan.org> - 0.99.0-5.20050803
- Update to 050803 and docs to 050705
- Rename packages *again* to be compatible with Fedora Extras

* Thu Jun  2 2005 Paul Howarth <paul@city-fan.org> - 0.99.0-5.20050531
- Update to 050531 version
- Incorporate documentation, version 050502
- Rename/reversion package for Fedora Extras compatibility
- Exclude libtidy.la, not needed

* Tue Feb 01 2005 Paul Howarth <paul@city-fan.org>
- Update to 050120 version

* Wed Oct 27 2004 Paul Howarth <paul@city-fan.org>
- Update to 041026 version

* Tue Jul 20 2004 Paul Howarth <paul@city-fan.org>
- Update to 040706 version

* Thu May 13 2004 Paul Howarth <paul@city-fan.org>
- Initial RPM build
